Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/diaspora/diaspora.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/lib
diff options
context:
space:
mode:
authorSteffen van Bergerem <svbergerem@online.de>2014-04-01 00:38:45 +0400
committerSteffen van Bergerem <svbergerem@online.de>2014-04-01 00:38:45 +0400
commit35b1ba088e8576c5d1a7720c975aaa0091015d7d (patch)
tree7c28391c246b696ea8d104119fb3c8bb03ced813 /lib
parentfaad980df0f6c7bb434f7b99bc0b041dcead4445 (diff)
Fix ui glitch in Bootstrap publisher
Diffstat (limited to 'lib')
-rw-r--r--lib/assets/javascripts/jquery.mentionsInput.js7
1 files changed, 4 insertions, 3 deletions
diff --git a/lib/assets/javascripts/jquery.mentionsInput.js b/lib/assets/javascripts/jquery.mentionsInput.js
index 17dca0f81..e1a73ff4c 100644
--- a/lib/assets/javascripts/jquery.mentionsInput.js
+++ b/lib/assets/javascripts/jquery.mentionsInput.js
@@ -9,8 +9,9 @@
*
* Modifcations for Diaspora:
*
* Prevent replacing the wrong text by marking the replacement position with a special character
* Don't add a space after inserting a mention
*/
(function ($, _, undefined) {
@@ -88,7 +89,7 @@
elmInputWrapper = elmInputBox.parent();
elmWrapperBox = $(settings.templates.wrapper());
elmInputBox.wrapAll(elmWrapperBox);
- elmWrapperBox = elmInputWrapper.find('> div');
+ elmWrapperBox = elmInputWrapper.find('> div').first();
elmInputBox.attr('data-mentions-input', 'true');
elmInputBox.bind('keydown', onInputBoxKeyDown);
@@ -9,8 +9,9 @@
* Modifcations for Diaspora:
*
- * Prevent replacing the wrong text by marking the replacement position with a special character
- * Don't add a space after inserting a mention
+ * Prevent replacing the wrong text by marking the replacement position with a special character
+ * Don't add a space after inserting a mention
+ * Only use the first div as a wrapperBox
*/
(function ($, _, undefined) {